import React, { useState } from "react";
import UheppHist from "./UheppHist.jsx";

const UheppHistUI = ({width, height, uhepp}) => {
  const [uhepp_data, setData] = useState(uhepp)

  const handleRebin = (e) => {
    let values = Array.from(e.target.selectedOptions, option => parseFloat(option.value))
    setData(Object.assign({}, uhepp_data,
      {bins: Object.assign({}, uhepp_data.bins, {rebin: values})}
    ))
  }

  const handleUnderflow = (e) => {
    let value = e.target.checked
    setData(Object.assign({}, uhepp_data,
      {bins: Object.assign({}, uhepp_data.bins, {include_underflow: value})}
    ))
  }
  const handleOverflow = (e) => {
    let value = e.target.checked
    setData(Object.assign({}, uhepp_data,
      {bins: Object.assign({}, uhepp_data.bins, {include_overflow: value})}
    ))
  }
  const handleDensityWidth = (e) => {
    let value = parseFloat(e.target.value)
    setData(Object.assign({}, uhepp_data,
      {bins: Object.assign({}, uhepp_data.bins, {density_width: value})}
    ))
  }

  let rebin = uhepp_data.bins.rebin || uhepp_data.bins.edges
  return <>
		<div>{ Object.entries(uhepp.metadata.tags).map(([key,  value]) => 
				value == null ?
				<span className="badge badge-pill badge-primary mx-1">{key}</span> :
				<span className="badge-pair mx-1">
					<span className="badge badge-pill badge-primary">{key}</span>
					<span className="badge badge-pill badge-secondary">{value}</span>
				</span>
				) }</div>
    <UheppHist width={width} height={height} uhepp={uhepp_data} />

		<ul className="nav nav-tabs" id="view-options" role="tablist">
			<li className="nav-item">
				<a className="nav-link active" id="info-tab" data-toggle="tab" href="#info" role="tab" aria-controls="info" aria-selected="true">Info</a>
			</li>
			<li className="nav-item">
				<a className="nav-link" id="binning-tab" data-toggle="tab" href="#binning" role="tab" aria-controls="binning" aria-selected="true">Binning</a>
			</li>
			<li className="nav-item">
				<a className="nav-link" id="other-tab" data-toggle="tab" href="#other" role="tab" aria-controls="other" aria-selected="false">Other</a>
			</li>
			<li className="nav-item">
				<a className="nav-link" id="reset-tab" data-toggle="tab" href="#reset" role="tab" aria-controls="reset" aria-selected="false">Reset</a>
			</li>
		</ul>

		<div className="tab-content" id="view-options-content">
			<div className="tab-pane show active" id="info" role="tabpanel" aria-labelledby="binning-tab">
				<dl>
					<dt>Author</dt>
					<dd>{ uhepp.metadata.author || <i>None</i>}</dd>
					<dt>Date</dt>
					<dd>{ uhepp.metadata.date ? (new Date(uhepp.metadata.date)).toString() : <i>None</i>}</dd>
					<dt>Producer</dt>
					<dd>{ uhepp.metadata.producer || <i>None</i>}</dd>
					<dt>Code revision</dt>
					<dd>{ uhepp.metadata.code_revision || <i>None</i>}</dd>
					<dt>Event selection</dt>
					<dd>{ uhepp.metadata.event_selection || <i>None</i>}</dd>
					<dt>Total integrated luminosity</dt>
					<dd>{ uhepp.metadata.lumi_ifb ?
								<span>{ uhepp.metadata.lumi_ifb} fb<sup>-1</sup></span> : <i>None</i>}</dd>
					<dt>Center-of-mass energy</dt>
					<dd>{ uhepp.metadata.Ecm_TeV ?
								uhepp.metadata.Ecm_TeV + " TeV" : <i>None</i>}</dd>
					<dt>Tags</dt>
					<dd>{ Object.entries(uhepp.metadata.tags).map(([key,  value]) => 
							value == null ?
							<span className="badge badge-pill badge-primary mx-1">{key}</span> :
							<span className="badge-pair mx-1">
								<span className="badge badge-pill badge-primary">{key}</span>
								<span className="badge badge-pill badge-secondary">{value}</span>
							</span>
							) }</dd>
				</dl>
			</div>
			<div className="tab-pane" id="binning" role="tabpanel" aria-labelledby="binning-tab">
				<form>
					<div className="form-group">
						<label htmlFor="rebin">Bin edges</label>
						<select multiple size={10} className="form-control" id="rebin" onChange={(e) => handleRebin(e)}>
							{uhepp.bins.edges.map((v, i) => 
								<option value={v} key={i} selected={rebin.indexOf(v) >= 0}>{v}</option>
							)}
						</select>
					</div>

					<div className="form-check">
						<input className="form-check-input" type="checkbox"
							checked={uhepp_data.bins.include_underflow == true} id="checkUnderflow"
							onChange={e => handleUnderflow(e)} />
						<label className="form-check-label" htmlFor="checkUnderflow">
							Include underflow events in first bin
						</label>
					</div>

					<div className="form-check">
						<input className="form-check-input" type="checkbox"
							checked={uhepp_data.bins.include_overflow == true} id="checkOverflow" 
							onChange={e => handleOverflow(e)} />
						<label className="form-check-label" htmlFor="checkOverflow">
							Include overflow events in last bin
						</label>
					</div>

					<div className="form-group">
						<label htmlFor="densityWidth">Normalize yields to</label>
						<div className="input-group">
							<input type="number" className="form-control" id="densityWidth"
								onChange={e => handleDensityWidth(e)}
								value={uhepp_data.bins.density_width || "0"} />
              { uhepp.variable.unit &&
                <div className="input-group-append">
                  <span className="input-group-text">{uhepp_data.variable.unit}</span>
                </div>
              }
						</div>
					</div>
				</form>
			</div>
			<div className="tab-pane" id="other" role="tabpanel" aria-labelledby="other-tab">
				<h1>La di da</h1>
			</div>
			<div className="tab-pane" id="reset" role="tabpanel" aria-labelledby="reset-tab">
				<button className="btn btn-secondary m-1" type="button" onClick={() => setData(uhepp)}>
					Reset view
				</button>
			</div>
		</div>
  </>
}
export default UheppHistUI;
